==> haskell-interpolate-0.2.1-323-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-8KDnKnvN208BeN8EkpPPWp
key:                  interpolate-0.2.1-8KDnKnvN208BeN8EkpPPWp
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  1d2d5f63ee48db5749f963b82ab24702
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.2.8/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-8KDnKnvN208BeN8EkpPPWp
depends:
    base-4.16.4.0 haskell-src-meta-0.8.12-3aFnqQE0XF33tohreEbzmX
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.1-382.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-GuIhBqxATV4In8gaOm4ORQ
key:                  interpolate-0.2.1-GuIhBqxATV4In8gaOm4ORQ
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  ecde6ff376371bb7fbc9bc6a6b5dabcd
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-GuIhBqxATV4In8gaOm4ORQ
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-2rjn8Wn2LvaEalb4n30kWZ
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
